pub fn build_dfir_code(
dfir_code: DfirCode,
root: &TokenStream,
) -> Result<BuildDfirCodeOutput, Diagnostics>Expand description
Compiles a DfirCode AST into inline source code that runs the dataflow.
pub fn build_dfir_code(
dfir_code: DfirCode,
root: &TokenStream,
) -> Result<BuildDfirCodeOutput, Diagnostics>Compiles a DfirCode AST into inline source code that runs the dataflow.