partition_graph

Function partition_graph 

pub fn partition_graph(
    flat_graph: DfirGraph,
) -> Result<DfirGraph, PartitionError>
Main method for this module. Partitions a flat DfirGraph into one with subgraphs.

Returns PartitionError if an intra-tick cycle exists in the graph. On error the original (pristine, un-partitioned) flat graph is handed back inside the error so it can still be rendered for debugging — see PartitionError.