DelayType

Enum DelayType 

pub enum DelayType {
    Stratum,
    MonotoneAccum,
    Tick,
    TickLazy,
}
The delay (soft barrier) type, for each input to an operator if needed.

Variants



Stratum

Input must be collected over the preceding stratum.



MonotoneAccum

Monotone accumulation: can delay to reduce flow rate, but also correct to emit “early”



Tick

Input must be collected over the previous tick.



TickLazy

Input must be collected over the previous tick but also not cause a new tick to occur.