pub fn postprocess_singletons(
tokens: TokenStream,
resolved_exprs: impl IntoIterator<Item = TokenStream>,
) -> Punctuated<Expr, Comma>Expand description
Replaces singleton references with the code needed to actually get the value inside.
tokens- The tokens to update singleton references within.resolved_exprs- Token streams that correspond 1:1 and in the same order as the singleton references withintokens(found in-order viapreprocess_singletons).
For shared refs: splices the resolved expression directly (e.g. &T or &Option<T>).
For mutable refs: splices the resolved expression directly (e.g. &mut T or &mut Option<T>).