pub fn postprocess_singletons(
tokens: TokenStream,
resolved_idents: impl IntoIterator<Item = Ident>,
) -> Punctuated<Expr, Comma>Expand description
Replaces singleton references #my_var with the code needed to actually get the value inside.
tokens- The tokens to update singleton references within.resolved_idents- The local variable idents that correspond 1:1 and in the same order as the singleton references withintokens(found in-order viapreprocess_singletons).
Generates (*&ident) — an immutable place expression that prevents consumer mutation.
Use postprocess_singletons_handles for just the raw idents.